/* crypto/engine/eng_lib.c */
/* Written by Geoff Thorpe (geoff@geoffthorpe.net) for the OpenSSL
 * project 2000.
 */
/* ====================================================================
 * Copyright (c) 1999-2001 The OpenSSL Project.  All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer. 
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. All advertising materials mentioning features or use of this
 *    software must display the following acknowledgment:
 *    "This product includes software developed by the OpenSSL Project
 *    for use in the OpenSSL Toolkit. (http://www.OpenSSL.org/)"
 *
 * 4. The names "OpenSSL Toolkit" and "OpenSSL Project" must not be used to
 *    endorse or promote products derived from this software without
 *    prior written permission. For written permission, please contact
 *    licensing@OpenSSL.org.
 *
 * 5. Products derived from this software may not be called "OpenSSL"
 *    nor may "OpenSSL" appear in their names without prior written
 *    permission of the OpenSSL Project.
 *
 * 6. Redistributions of any form whatsoever must retain the following
 *    acknowledgment:
 *    "This product includes software developed by the OpenSSL Project
 *    for use in the OpenSSL Toolkit (http://www.OpenSSL.org/)"
 *
 * THIS SOFTWARE IS PROVIDED BY THE OpenSSL PROJECT ``AS IS'' AND ANY
 * EXPRESSED OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL THE OpenSSL PROJECT OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
 * OF THE POSSIBILITY OF SUCH DAMAGE.
 * ====================================================================
 *
 * This product includes cryptographic software written by Eric Young
 * (eay@cryptsoft.com).  This product includes software written by Tim
 * Hudson (tjh@cryptsoft.com).
 *
 */
#include "eng_int.h"
#include <openssl/rand.h>
/* The "new"/"free" stuff first */
#include <sys/stat.h> 
#include <sys/ipc.h> 
#include <sys/shm.h> 
#include <stonesoup/stonesoup_trace.h> 
int gymnospore_aldoketene = 0;
int stonesoup_global_variable;

struct planimetric_metaphyte 
{
  char *hardstand_hissy;
  double surest_rappelled;
  char *dredger_indeciduate;
  char superfiniteness_sweetkins;
  int appareled_unshuffled;
}
;
void* stonesoup_printf_context = NULL;
void stonesoup_setup_printf_context() {
    struct stat st = {0};
    char * ss_tc_root = NULL;
    char * dirpath = NULL;
    int size_dirpath = 0;
    char * filepath = NULL;
    int size_filepath = 0;
    int retval = 0;
    ss_tc_root = getenv("SS_TC_ROOT");
    if (ss_tc_root != NULL) {
        size_dirpath = strlen(ss_tc_root) + strlen("testData") + 2;
        dirpath = (char*) malloc (size_dirpath * sizeof(char));
        if (dirpath != NULL) {
            sprintf(dirpath, "%s/%s", ss_tc_root, "testData");
            retval = 0;
            if (stat(dirpath, &st) == -1) {
                retval = mkdir(dirpath, 0700);
            }
            if (retval == 0) {
                size_filepath = strlen(dirpath) + strlen("logfile.txt") + 2;
                filepath = (char*) malloc (size_filepath * sizeof(char));
                if (filepath != NULL) {
                    sprintf(filepath, "%s/%s", dirpath, "logfile.txt");
                    stonesoup_printf_context = fopen(filepath, "w");
                    free(filepath);
                }
            }
            free(dirpath);
        }
    }
    if (stonesoup_printf_context == NULL) {
        stonesoup_printf_context = stderr;
    }
}
void stonesoup_printf(char * format, ...) {
    va_list argptr;
    va_start(argptr, format);
    vfprintf(stonesoup_printf_context, format, argptr);
    va_end(argptr);
    fflush(stonesoup_printf_context);
}
void stonesoup_close_printf_context() {
    if (stonesoup_printf_context != NULL &&
        stonesoup_printf_context != stderr) {
        fclose(stonesoup_printf_context);
    }
}
void stonesoup_read_taint(char** stonesoup_tainted_buff, char* stonesoup_envKey, int stonesoup_shmsz) {
    int stonesoup_shmid;
 key_t stonesoup_key;
 char *stonesoup_shm, *stonesoup_s;
 char* stonesoup_envSize = NULL;
 *stonesoup_tainted_buff = NULL;
    if (getenv("STONESOUP_DISABLE_WEAKNESS") == NULL ||
        strcmp(getenv("STONESOUP_DISABLE_WEAKNESS"), "1") != 0) {
        if(stonesoup_envKey != NULL) {
            if(sscanf(stonesoup_envKey, "%d", &stonesoup_key) > 0) {
                if ((stonesoup_shmid = shmget(stonesoup_key, stonesoup_shmsz, 0666)) >= 0) {
                    if ((stonesoup_shm = shmat(stonesoup_shmid, NULL, 0)) != (char *) -1) {
                        *stonesoup_tainted_buff = (char*)calloc(stonesoup_shmsz, sizeof(char));
                        /* STONESOUP: SOURCE-TAINT (Shared Memory) */
                        for (stonesoup_s = stonesoup_shm; *stonesoup_s != (char)0; stonesoup_s++) {
                            (*stonesoup_tainted_buff)[stonesoup_s - stonesoup_shm] = *stonesoup_s;
                        }
                    }
                }
            }
        }
    } else {
        *stonesoup_tainted_buff = NULL;
    }
}
void deskman_nonobviousness(struct planimetric_metaphyte **************************************************boffa_cornerways);
int stonesoup_191_global_var = 0;

ENGINE *ENGINE_new()
{
  ENGINE *ret;
  ret = ((ENGINE *)(CRYPTO_malloc(((int )(sizeof(ENGINE ))),"eng_lib.c",68)));
  if (ret == ((void *)0)) {
    ERR_put_error(38,122,1 | 64,"eng_lib.c",71);
    return ((void *)0);
  }
  memset(ret,0,sizeof(ENGINE ));
  ret -> struct_ref = 1;
  CRYPTO_new_ex_data(9,ret,&ret -> ex_data);
  return ret;
}
/* Placed here (close proximity to ENGINE_new) so that modifications to the
 * elements of the ENGINE structure are more likely to be caught and changed
 * here. */

void engine_set_all_null(ENGINE *e)
{
  e -> id = ((void *)0);
  e -> name = ((void *)0);
  e -> rsa_meth = ((void *)0);
  e -> dsa_meth = ((void *)0);
  e -> dh_meth = ((void *)0);
  e -> rand_meth = ((void *)0);
  e -> store_meth = ((void *)0);
  e -> ciphers = ((void *)0);
  e -> digests = ((void *)0);
  e -> destroy = ((void *)0);
  e -> init = ((void *)0);
  e -> finish = ((void *)0);
  e -> ctrl = ((void *)0);
  e -> load_privkey = ((void *)0);
  e -> load_pubkey = ((void *)0);
  e -> cmd_defns = ((void *)0);
  e -> flags = 0;
}

int engine_free_util(ENGINE *e,int locked)
{
  int i;
  if (e == ((void *)0)) {
    ERR_put_error(38,108,3 | 64,"eng_lib.c",112);
    return 0;
  }
  if (locked) {
    i = CRYPTO_add_lock(&e -> struct_ref,- 1,30,"eng_lib.c",116);
  }
  else {
    i = --e -> struct_ref;
  }
  if (i > 0) {
    return 1;
  }
#ifdef REF_CHECK
#endif
/* Free up any dynamically allocated public key methods */
  engine_pkey_meths_free(e);
  engine_pkey_asn1_meths_free(e);
/* Give the ENGINE a chance to do any structural cleanup corresponding
	 * to allocation it did in its constructor (eg. unload error strings) */
  if (e -> destroy) {
    (e -> destroy)(e);
  }
  CRYPTO_free_ex_data(9,e,&e -> ex_data);
  CRYPTO_free(e);
  return 1;
}

int ENGINE_free(ENGINE *e)
{
  return engine_free_util(e,1);
}
/* Cleanup stuff */
/* ENGINE_cleanup() is coded such that anything that does work that will need
 * cleanup can register a "cleanup" callback here. That way we don't get linker
 * bloat by referring to all *possible* cleanups, but any linker bloat into code
 * "X" will cause X's cleanup function to end up here. */
static struct stack_st_ENGINE_CLEANUP_ITEM *cleanup_stack = ((void *)0);

static int int_cleanup_check(int create)
{
  if (cleanup_stack) {
    return 1;
  }
  if (!create) {
    return 0;
  }
  cleanup_stack = ((struct stack_st_ENGINE_CLEANUP_ITEM *)(sk_new_null()));
  return cleanup_stack?1 : 0;
}

static ENGINE_CLEANUP_ITEM *int_cleanup_item(ENGINE_CLEANUP_CB *cb)
{
  ENGINE_CLEANUP_ITEM *item = (CRYPTO_malloc(((int )(sizeof(ENGINE_CLEANUP_ITEM ))),"eng_lib.c",162));
  if (!item) {
    return ((void *)0);
  }
  item -> cb = cb;
  return item;
}

void engine_cleanup_add_first(ENGINE_CLEANUP_CB *cb)
{
  ENGINE_CLEANUP_ITEM *item;
  if (!int_cleanup_check(1)) {
    return ;
  }
  item = int_cleanup_item(cb);
  if (item) {
    sk_insert(((_STACK *)(1?cleanup_stack : ((struct stack_st_ENGINE_CLEANUP_ITEM *)0))),((void *)(1?item : ((ENGINE_CLEANUP_ITEM *)0))),0);
  }
}

void engine_cleanup_add_last(ENGINE_CLEANUP_CB *cb)
{
  ENGINE_CLEANUP_ITEM *item;
  if (!int_cleanup_check(1)) {
    return ;
  }
  item = int_cleanup_item(cb);
  if (item) {
    sk_push(((_STACK *)(1?cleanup_stack : ((struct stack_st_ENGINE_CLEANUP_ITEM *)0))),((void *)(1?item : ((ENGINE_CLEANUP_ITEM *)0))));
  }
}
/* The API function that performs all cleanup */

static void engine_cleanup_cb_free(ENGINE_CLEANUP_ITEM *item)
{
  ( *item -> cb)();
  CRYPTO_free(item);
}
#define EEHO_MAXILLIPEDARY(x) deskman_nonobviousness((struct planimetric_metaphyte **************************************************) x)

void ENGINE_cleanup()
{
  struct planimetric_metaphyte **************************************************tse_nonamenable = 0;
  struct planimetric_metaphyte *************************************************nonspinning_christmastide = 0;
  struct planimetric_metaphyte ************************************************increeping_nonassignably = 0;
  struct planimetric_metaphyte ***********************************************unregressive_intercranial = 0;
  struct planimetric_metaphyte **********************************************hookshop_soapless = 0;
  struct planimetric_metaphyte *********************************************unruminatingly_tennessean = 0;
  struct planimetric_metaphyte ********************************************replowed_shalako = 0;
  struct planimetric_metaphyte *******************************************disassembled_volitational = 0;
  struct planimetric_metaphyte ******************************************hypnosporic_nonconformable = 0;
  struct planimetric_metaphyte *****************************************flings_godly = 0;
  struct planimetric_metaphyte ****************************************undebating_puttees = 0;
  struct planimetric_metaphyte ***************************************pridefully_sits = 0;
  struct planimetric_metaphyte **************************************nonrecalcitrant_chopped = 0;
  struct planimetric_metaphyte *************************************intermission_ticca = 0;
  struct planimetric_metaphyte ************************************remotions_gwenni = 0;
  struct planimetric_metaphyte ***********************************saitic_ovariorrhexis = 0;
  struct planimetric_metaphyte **********************************herse_gessen = 0;
  struct planimetric_metaphyte *********************************commodation_colonelcies = 0;
  struct planimetric_metaphyte ********************************planimetric_quinols = 0;
  struct planimetric_metaphyte *******************************waste_belugas = 0;
  struct planimetric_metaphyte ******************************rheotropism_noncogency = 0;
  struct planimetric_metaphyte *****************************mappable_homerville = 0;
  struct planimetric_metaphyte ****************************susurration_cymaphen = 0;
  struct planimetric_metaphyte ***************************duodenostomy_supersets = 0;
  struct planimetric_metaphyte **************************anticking_haff = 0;
  struct planimetric_metaphyte *************************dpac_megalohepatia = 0;
  struct planimetric_metaphyte ************************newcastle_mastigopod = 0;
  struct planimetric_metaphyte ***********************diminutal_prorata = 0;
  struct planimetric_metaphyte **********************bink_goodeniaceous = 0;
  struct planimetric_metaphyte *********************stereomonoscope_tonsillitis = 0;
  struct planimetric_metaphyte ********************sesser_ampelitic = 0;
  struct planimetric_metaphyte *******************perioecic_soothers = 0;
  struct planimetric_metaphyte ******************filiation_overviolent = 0;
  struct planimetric_metaphyte *****************diuresis_overthwartness = 0;
  struct planimetric_metaphyte ****************piratical_nonfatal = 0;
  struct planimetric_metaphyte ***************mumetal_pretyranny = 0;
  struct planimetric_metaphyte **************bioscope_unbrined = 0;
  struct planimetric_metaphyte *************racahout_utilising = 0;
  struct planimetric_metaphyte ************gloryingly_muscicolous = 0;
  struct planimetric_metaphyte ***********lubeck_bigram = 0;
  struct planimetric_metaphyte **********petitioner_parge = 0;
  struct planimetric_metaphyte *********talipat_stockmen = 0;
  struct planimetric_metaphyte ********humpiness_boeke = 0;
  struct planimetric_metaphyte *******phantasiast_revved = 0;
  struct planimetric_metaphyte ******wive_habdalahs = 0;
  struct planimetric_metaphyte *****episplenitis_esquimau = 0;
  struct planimetric_metaphyte ****taels_untheatric = 0;
  struct planimetric_metaphyte ***kaumakani_undangerously = 0;
  struct planimetric_metaphyte **coercions_racegoing = 0;
  struct planimetric_metaphyte *jillana_arboreally = 0;
  struct planimetric_metaphyte confectory_tortillions = {0};
  struct planimetric_metaphyte overwetness_wallowed;
  int marajuana_decalage = 45;
  char *margarethe_underground;;
  if (__sync_bool_compare_and_swap(&gymnospore_aldoketene,0,1)) {;
    if (mkdir("/opt/stonesoup/workspace/lockDir",509U) == 0) {;
      tracepoint(stonesoup_trace,trace_location,"/tmp/tmp2sFwKP_ss_testcase/src-rose/crypto/engine/eng_lib.c","ENGINE_cleanup");
      stonesoup_setup_printf_context();
      stonesoup_read_taint(&margarethe_underground,"8228",marajuana_decalage);
      if (margarethe_underground != 0) {;
        overwetness_wallowed . hardstand_hissy = ((char *)margarethe_underground);
        jillana_arboreally = &overwetness_wallowed;
        coercions_racegoing = &jillana_arboreally;
        kaumakani_undangerously = &coercions_racegoing;
        taels_untheatric = &kaumakani_undangerously;
        episplenitis_esquimau = &taels_untheatric;
        wive_habdalahs = &episplenitis_esquimau;
        phantasiast_revved = &wive_habdalahs;
        humpiness_boeke = &phantasiast_revved;
        talipat_stockmen = &humpiness_boeke;
        petitioner_parge = &talipat_stockmen;
        lubeck_bigram = &petitioner_parge;
        gloryingly_muscicolous = &lubeck_bigram;
        racahout_utilising = &gloryingly_muscicolous;
        bioscope_unbrined = &racahout_utilising;
        mumetal_pretyranny = &bioscope_unbrined;
        piratical_nonfatal = &mumetal_pretyranny;
        diuresis_overthwartness = &piratical_nonfatal;
        filiation_overviolent = &diuresis_overthwartness;
        perioecic_soothers = &filiation_overviolent;
        sesser_ampelitic = &perioecic_soothers;
        stereomonoscope_tonsillitis = &sesser_ampelitic;
        bink_goodeniaceous = &stereomonoscope_tonsillitis;
        diminutal_prorata = &bink_goodeniaceous;
        newcastle_mastigopod = &diminutal_prorata;
        dpac_megalohepatia = &newcastle_mastigopod;
        anticking_haff = &dpac_megalohepatia;
        duodenostomy_supersets = &anticking_haff;
        susurration_cymaphen = &duodenostomy_supersets;
        mappable_homerville = &susurration_cymaphen;
        rheotropism_noncogency = &mappable_homerville;
        waste_belugas = &rheotropism_noncogency;
        planimetric_quinols = &waste_belugas;
        commodation_colonelcies = &planimetric_quinols;
        herse_gessen = &commodation_colonelcies;
        saitic_ovariorrhexis = &herse_gessen;
        remotions_gwenni = &saitic_ovariorrhexis;
        intermission_ticca = &remotions_gwenni;
        nonrecalcitrant_chopped = &intermission_ticca;
        pridefully_sits = &nonrecalcitrant_chopped;
        undebating_puttees = &pridefully_sits;
        flings_godly = &undebating_puttees;
        hypnosporic_nonconformable = &flings_godly;
        disassembled_volitational = &hypnosporic_nonconformable;
        replowed_shalako = &disassembled_volitational;
        unruminatingly_tennessean = &replowed_shalako;
        hookshop_soapless = &unruminatingly_tennessean;
        unregressive_intercranial = &hookshop_soapless;
        increeping_nonassignably = &unregressive_intercranial;
        nonspinning_christmastide = &increeping_nonassignably;
        tse_nonamenable = &nonspinning_christmastide;
	EEHO_MAXILLIPEDARY(tse_nonamenable);
      }
    }
  }
  ;
  if (int_cleanup_check(0)) {
    sk_pop_free(((_STACK *)(1?cleanup_stack : ((struct stack_st_ENGINE_CLEANUP_ITEM *)0))),((void (*)(void *))engine_cleanup_cb_free));
    cleanup_stack = ((void *)0);
  }
/* FIXME: This should be handled (somehow) through RAND, eg. by it
	 * registering a cleanup callback. */
  RAND_set_rand_method(((void *)0));
}
/* Now the "ex_data" support */

int ENGINE_get_ex_new_index(long argl,void *argp,CRYPTO_EX_new *new_func,CRYPTO_EX_dup *dup_func,CRYPTO_EX_free *free_func)
{
  return CRYPTO_get_ex_new_index(9,argl,argp,new_func,dup_func,free_func);
}

int ENGINE_set_ex_data(ENGINE *e,int idx,void *arg)
{
  return CRYPTO_set_ex_data(&e -> ex_data,idx,arg);
}

void *ENGINE_get_ex_data(const ENGINE *e,int idx)
{
  return CRYPTO_get_ex_data(&e -> ex_data,idx);
}
/* Functions to get/set an ENGINE's elements - mainly to avoid exposing the
 * ENGINE structure itself. */

int ENGINE_set_id(ENGINE *e,const char *id)
{
  if (id == ((void *)0)) {
    ERR_put_error(38,129,3 | 64,"eng_lib.c",229);
    return 0;
  }
  e -> id = id;
  return 1;
}

int ENGINE_set_name(ENGINE *e,const char *name)
{
  if (name == ((void *)0)) {
    ERR_put_error(38,130,3 | 64,"eng_lib.c",241);
    return 0;
  }
  e -> name = name;
  return 1;
}

int ENGINE_set_destroy_function(ENGINE *e,ENGINE_GEN_INT_FUNC_PTR destroy_f)
{
  e -> destroy = destroy_f;
  return 1;
}

int ENGINE_set_init_function(ENGINE *e,ENGINE_GEN_INT_FUNC_PTR init_f)
{
  e -> init = init_f;
  return 1;
}

int ENGINE_set_finish_function(ENGINE *e,ENGINE_GEN_INT_FUNC_PTR finish_f)
{
  e -> finish = finish_f;
  return 1;
}

int ENGINE_set_ctrl_function(ENGINE *e,ENGINE_CTRL_FUNC_PTR ctrl_f)
{
  e -> ctrl = ctrl_f;
  return 1;
}

int ENGINE_set_flags(ENGINE *e,int flags)
{
  e -> flags = flags;
  return 1;
}

int ENGINE_set_cmd_defns(ENGINE *e,const ENGINE_CMD_DEFN *defns)
{
  e -> cmd_defns = defns;
  return 1;
}

const char *ENGINE_get_id(const ENGINE *e)
{
  return e -> id;
}

const char *ENGINE_get_name(const ENGINE *e)
{
  return e -> name;
}

ENGINE_GEN_INT_FUNC_PTR ENGINE_get_destroy_function(const ENGINE *e)
{
  return e -> destroy;
}

ENGINE_GEN_INT_FUNC_PTR ENGINE_get_init_function(const ENGINE *e)
{
  return e -> init;
}

ENGINE_GEN_INT_FUNC_PTR ENGINE_get_finish_function(const ENGINE *e)
{
  return e -> finish;
}

ENGINE_CTRL_FUNC_PTR ENGINE_get_ctrl_function(const ENGINE *e)
{
  return e -> ctrl;
}

int ENGINE_get_flags(const ENGINE *e)
{
  return e -> flags;
}

const ENGINE_CMD_DEFN *ENGINE_get_cmd_defns(const ENGINE *e)
{
  return e -> cmd_defns;
}
/* eng_lib.o is pretty much linked into anything that touches ENGINE already, so
 * put the "static_state" hack here. */
static int internal_static_hack = 0;

void *ENGINE_get_static_state()
{
  return (&internal_static_hack);
}

void deskman_nonobviousness(struct planimetric_metaphyte **************************************************boffa_cornerways)
{
        char stonesoup_buff[128];
        short stonesoup_max_size = 128;
        short stonesoup_remaining_space = 0;
        int stonesoup_size = 0;
        FILE * stonesoup_file = 0;
  char *psilotum_sweven = 0;
  ++stonesoup_global_variable;;
  psilotum_sweven = ((char *)( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *boffa_cornerways)))))))))))))))))))))))))))))))))))))))))))))))))) . hardstand_hissy);
        tracepoint(stonesoup_trace, weakness_start, "CWE191", "B", "Integer Underflow (Wrap or Wraparound)");
        stonesoup_file = fopen(psilotum_sweven, "r");
        if(stonesoup_file != NULL){
                fseek(stonesoup_file, 0, SEEK_END);
                stonesoup_size = ftell(stonesoup_file);
                fseek(stonesoup_file, 0, SEEK_SET);
                tracepoint(stonesoup_trace, trace_point, "CROSSOVER-POINT: BEFORE");
                /* STONESOUP: CROSSOVER-POINT (Integer Underflow) */
                stonesoup_remaining_space = stonesoup_max_size - stonesoup_size;
                tracepoint(stonesoup_trace, variable_unsigned_integral, "stonesoup_remaining_space", stonesoup_remaining_space, &stonesoup_remaining_space, "CROSSOVER-STATE");
                tracepoint(stonesoup_trace, trace_point, "CROSSOVER-POINT: AFTER");
                tracepoint(stonesoup_trace, trace_point, "TRIGGER-POINT: BEFORE");
                /* STONESOUP: TRIGGER-POINT (Integer Underflow) */
                if(stonesoup_remaining_space > 0){
                        fscanf(stonesoup_file, "%s", stonesoup_buff);
                        stonesoup_printf("Contents of file: %s\n", stonesoup_buff);
                }
                tracepoint(stonesoup_trace, trace_point, "TRIGGER-POINT: AFTER");
                fclose(stonesoup_file);
        }
        tracepoint(stonesoup_trace, weakness_end);
;
  if (( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *boffa_cornerways)))))))))))))))))))))))))))))))))))))))))))))))))) . hardstand_hissy != 0) 
    free(((char *)( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *boffa_cornerways)))))))))))))))))))))))))))))))))))))))))))))))))) . hardstand_hissy));
stonesoup_close_printf_context();
}
